import styled from '@emotion/styled'
import { Layout, Spin, Typography } from 'antd'
import { Content, Footer } from 'antd/lib/layout/layout'
import { useEffect } from 'react'
import { useSelector } from 'react-redux'
import { NavLink, Route, Routes, useNavigate } from 'react-router-dom'
import './App.css'
import { AuctionView } from './container/auction/AuctionView'
import { BiddedAuctionView } from './container/auction/BiddedAuctionView'
import { CreateAuctionContainer } from './container/auction/CreateAuctionContainer'
import { CreateAuctionView } from './container/auction/CreateAuctionView'
import { CreatedAuctionView } from './container/auction/CreatedAuctionView'
import Home from './container/home/Home'
import LoginView from './container/login/LoginView'
import SignupView from './container/login/SignupView'
import { UserDropdown } from './container/login/UserDropdown'
import PrivateRoute from './container/PrivateRoute'
import { CreateProductContainer } from './container/product/CreateProductContainer'
import { CreateProductView } from './container/product/CreateProductView'
import { ProductScreen } from './container/product/ProductScreen'
import { useAppDispatch } from './store'
import { web3Actions } from './store/reducer/web3Reducer'
import { web3Selector } from './store/selector/web3Selector'

function App() {
    const dispatch = useAppDispatch()
    const isSignup = useSelector(web3Selector.isSignup)
    const isEmailLoading = useSelector(web3Selector.isEmailLoading)
    const navigate = useNavigate()
    const user = useSelector(web3Selector.user)

    useEffect(() => {
        dispatch(web3Actions.getUser())
    }, [])

    if (isEmailLoading) {
        return (
            <LoadingContainer>
                <Spin tip="계좌정보를 로딩중입니다..." />
            </LoadingContainer>
        )
    }

    return (
        <Layout style={{ background: 'white', height: '100vh' }}>
            <Header style={{ padding: 6 }}>
                <div onClick={() => navigate('/')}>
                    <img
                        src="/anjun-logo.png"
                        style={{ width: 120 }}
                        alt="logo"
                    />
                </div>
                <div style={{ display: 'flex', flexDirection: 'row' }}>
                    <NavLink
                        to="/"
                        style={({ isActive }) => ({
                            fontWeight: 'bold',
                            padding: '0 12px',
                            color: isActive ? '#9e593c' : 'black',
                        })}
                    >
                        매물찾기
                    </NavLink>
                    <NavLink
                        to="/auction/bidded"
                        style={({ isActive }) => ({
                            fontWeight: 'bold',
                            padding: '0 12px',
                            color: isActive ? '#9e593c' : 'black',
                        })}
                    >
                        내가 입찰한 경매
                    </NavLink>
                    <NavLink
                        to="/auction/my"
                        style={({ isActive }) => ({
                            fontWeight: 'bold',
                            padding: '0 12px',
                            color: isActive ? '#9e593c' : 'black',
                        })}
                    >
                        나의 경매
                    </NavLink>
                    <NavLink
                        to="/product"
                        style={({ isActive }) => ({
                            fontWeight: 'bold',
                            padding: '0 12px',
                            color: isActive ? '#9e593c' : 'black',
                        })}
                    >
                        나의 매물
                    </NavLink>
                    {!isSignup && (
                        <NavLink
                            to="/login"
                            style={({ isActive }) => ({
                                fontWeight: 'bold',
                                padding: '0 12px',
                                color: isActive ? '#9e593c' : 'black',
                            })}
                        >
                            로그인
                        </NavLink>
                    )}
                    <UserDropdown />
                </div>
            </Header>
            <Content style={{ overflow: 'hidden' }}>
                <Routes>
                    <Route path="/" element={<AuctionView />} />
                    <Route
                        path="auction/*"
                        element={
                            <PrivateRoute>
                                <Routes>
                                    <Route
                                        path="bidded"
                                        element={<BiddedAuctionView />}
                                    />
                                    <Route
                                        path="my"
                                        element={<CreatedAuctionView />}
                                    />
                                    <Route
                                        path="create"
                                        element={<CreateAuctionContainer />}
                                    />
                                </Routes>
                            </PrivateRoute>
                        }
                    />

                    <Route
                        path="product/*"
                        element={
                            <PrivateRoute>
                                <Routes>
                                    <Route
                                        path=""
                                        element={<ProductScreen />}
                                    />
                                    <Route
                                        path="create"
                                        element={<CreateProductContainer />}
                                    />
                                </Routes>
                            </PrivateRoute>
                        }
                    />

                    <Route path="/login" element={<LoginView />} />

                    <Route path="/signup" element={<SignupView />} />
                </Routes>
            </Content>
            <Footer style={{ textAlign: 'center' }}>
                안전방 ©2022 Created by hangbok
            </Footer>
        </Layout>
    )
}

const LoadingContainer = styled.div({
    width: '100vw',
    height: '100vh',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
})

// const Link = styled(NavLink)(({ active }: { active: boolean }) => ({
//     color: active ? '#9e593c' : 'black',
// }))

const Header = styled.div({
    display: 'flex',
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
})

export default App
