import styled from '@emotion/styled'
import { Tabs } from 'antd'
import _ from 'lodash'
import { useEffect } from 'react'
import { useAppDispatch } from '../../store'
import { Auction } from '../../store/model/Auction'
import { auctionActions } from '../../store/reducer/aunctionReducer'
import { AuctionListContainer } from './AuctionView/AuctionListContainer'

const { TabPane } = Tabs

interface Props {
    completedAuctions: Array<Auction>
    processingAuctions: Array<Auction>
    auction?: Auction
    onClickTab: (auctionId: number) => void
}

export function AuctionBaseView({
    completedAuctions,
    processingAuctions,
    auction,
    onClickTab,
}: Props) {
    const onTabClick = (activeKey: string) => {
        if (activeKey === '1') {
            onClickTab(_.get(processingAuctions, 0)?.auctionId)
        } else {
            onClickTab(_.get(completedAuctions, 0)?.auctionId)
        }
    }

    return (
        <Header>
            <Tabs
                style={{ height: '100%' }}
                defaultActiveKey="1"
                destroyInactiveTabPane
                onTabClick={onTabClick}
            >
                <TabPane tab="진행" key="1" style={{ height: '100%' }}>
                    <AuctionListContainer
                        auctions={processingAuctions}
                        auction={auction}
                    />
                </TabPane>
                <TabPane tab="종료" key="2" style={{ height: '100%' }}>
                    <AuctionListContainer
                        auctions={completedAuctions}
                        auction={auction}
                    />
                </TabPane>
            </Tabs>
        </Header>
    )
}

const Header = styled.div({
    width: '100%',
    height: '100%',
    padding: '24px 24px 0 24px',
})
