import styled from '@emotion/styled'
import { Button, Typography } from 'antd'
import { useEffect } from 'react'
import { useNavigate } from 'react-router-dom'
import { useAppDispatch } from '../../../store'
import { Auction } from '../../../store/model/Auction'
import { auctionActions } from '../../../store/reducer/aunctionReducer'
import { AuctionSummaryView } from './AuctionSummaryView'

interface Props {
    auctions: Array<Auction>
    auctionId?: number
}

export function AuctionList({ auctions, auctionId }: Props) {
    const navigate = useNavigate()

    return (
        <AuctionListContainer>
            <Header>
                <Typography.Text
                    strong
                >{`경매 목록 ${auctions.length}개`}</Typography.Text>
                <Button
                    type="primary"
                    onClick={() => navigate('/auction/create')}
                >
                    경매 생성하기
                </Button>
            </Header>

            {auctions.map((auction) => (
                <AuctionSummaryView
                    key={auction.auctionId}
                    auction={auction}
                    selectedAuctionId={auctionId}
                />
            ))}
        </AuctionListContainer>
    )
}

const AuctionListContainer = styled.div({
    display: 'flex',
    flexDirection: 'column',
    borderRight: '1px solid #F0F0F0;',
    minWidth: 420,
    maxWidth: 420,
    overflow: 'scroll',
})

const Header = styled.div({
    display: 'flex',
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    padding: 12,
    borderTop: '1px solid #F0F0F0;',
    borderBottom: '1px solid #F0F0F0',
})
