import styled from '@emotion/styled'
import { Image, message, Typography } from 'antd'
import _ from 'lodash'
import moment from 'moment'
import { useCallback, useEffect, useState } from 'react'
import { useSelector } from 'react-redux'
import { useAppDispatch } from '../../../store'
import { Auction } from '../../../store/model/Auction'
import { auctionActions } from '../../../store/reducer/aunctionReducer'
import { bidActions } from '../../../store/reducer/bidReducer'
import { web3Selector } from '../../../store/selector/web3Selector'
import { BidModal } from './BidModal'

interface Props {
    auction: Auction
    selectedAuctionId?: number
}

export function AuctionSummaryView({ auction, selectedAuctionId }: Props) {
    const dispatch = useAppDispatch()
    const userId = useSelector(web3Selector.userId)

    const { auctionId, product, description, bids, endAt, title } = auction

    const { address, roomArchitecture, area, imageUrls } = product

    const currentPrice = _.get(bids, 0)?.price ?? 0

    const handleAuctionClick = useCallback(() => {
        console.log('auctionId', auctionId)
        dispatch(auctionActions.selectAuction(auctionId))
    }, [auctionId])

    return (
        <AuctionContainer
            onClick={handleAuctionClick}
            style={{ cursor: 'pointer' }}
            selected={auctionId === selectedAuctionId}
        >
            <Image
                style={{ minWidth: 200 }}
                width={200}
                height={200}
                src={_.get(imageUrls, 0) ?? '/anjun-logo.png'}
                preview={false}
            />

            <DescriptionContainer>
                <Typography.Text>{title}</Typography.Text>
                <Typography.Text>
                    종료일시: {moment(endAt).format('YYYY-MM-DD')}
                </Typography.Text>
                <Typography.Text>
                    현재 경매가: {currentPrice} ETF
                </Typography.Text>
                <Typography.Text>{address}</Typography.Text>
                <Typography.Text>{roomArchitecture}</Typography.Text>
                <Typography.Text>
                    {area}m<sup>2</sup>
                </Typography.Text>
                <Typography.Paragraph
                    style={{ whiteSpace: 'pre-wrap', wordBreak: 'break-all' }}
                    ellipsis={{
                        rows: 4,
                        tooltip: description,
                    }}
                >
                    {description}
                </Typography.Paragraph>
            </DescriptionContainer>
        </AuctionContainer>
    )
}

const AuctionContainer = styled.div(({ selected }: { selected: boolean }) => ({
    display: 'flex',
    flexDirection: 'row',
    padding: 10,
    backgroundColor: selected ? '#fafafa' : 'white',
    minWidth: 420,
    maxWidth: 420,
}))

const DescriptionContainer = styled.div({
    display: 'flex',
    flexDirection: 'column',
    padding: 10,
})
