import { InputNumber, Modal, Typography } from 'antd'
import _ from 'lodash'
import { useState } from 'react'
import { Auction } from '../../../store/model/Auction'

interface Props {
    auction: Auction
    isModalVisible: boolean
    handleOk: (data: number) => void
    handleCancel: () => void
}

export function BidModal({
    auction,
    isModalVisible,
    handleOk,
    handleCancel,
}: Props) {
    const highestPrice = _.get(auction.bids, 0)?.price ?? 0
    const [price, setPrice] = useState(highestPrice)

    return (
        <Modal
            title="입찰하기"
            visible={isModalVisible}
            onOk={() => handleOk(price)}
            onCancel={handleCancel}
        >
            <div style={{ display: 'flex', flexDirection: 'column' }}>
                <Typography.Text strong>
                    최고입찰액: {highestPrice}
                </Typography.Text>
                <InputNumber
                    value={price}
                    addonAfter="ETF"
                    onChange={(value) => setPrice(value)}
                    min={highestPrice}
                />
            </div>
        </Modal>
    )
}
