import styled from '@emotion/styled'
import { Button, Form, Input, Result } from 'antd'
import { useForm } from 'antd/lib/form/Form'
import { initial } from 'lodash'
import { useCallback, useEffect, useMemo } from 'react'
import { useSelector } from 'react-redux'
import { useNavigate } from 'react-router-dom'
import { useAppDispatch } from '../../store'
import { web3Actions } from '../../store/reducer/web3Reducer'
import { web3Selector } from '../../store/selector/web3Selector'

interface FormData {
    email: string
    nickname: string
    password: string
}

function SignupView() {
    const dispatch = useAppDispatch()
    const navigate = useNavigate()

    const [form] = useForm<FormData>()

    const email = useSelector(web3Selector.email)

    const initialValues = useMemo(
        () => ({
            nickname: '',
            password: '',
            email,
        }),
        [],
    )

    useEffect(() => {
        form.setFieldsValue(initialValues)
    }, [initialValues])

    const handleSignup = useCallback((data: FormData) => {
        dispatch(web3Actions.signup(data)).then(() => {
            navigate('/')
        })
    }, [])

    if (email === undefined) {
        return (
            <Result
                status="500"
                title="500"
                subTitle="MetaMask에 계좌정보가 없습니다. 계좌를 가져와주세요."
            />
        )
    }

    return (
        <FormContainer>
            <Form
                labelCol={{ span: 8 }}
                wrapperCol={{ span: 16 }}
                form={form}
                initialValues={initial}
                onFinish={handleSignup}
            >
                <Form.Item name="email" label="지갑주소">
                    <Input disabled />
                </Form.Item>

                <Form.Item required name="password" label="비밀번호">
                    <Input type="password" />
                </Form.Item>

                <Form.Item required name="nickname" label="이름">
                    <Input />
                </Form.Item>
                <Form.Item wrapperCol={{ offset: 8, span: 16 }}>
                    <Button type="primary" htmlType="submit">
                        회원가입
                    </Button>
                </Form.Item>
            </Form>
        </FormContainer>
    )
}

export default SignupView

const FormContainer = styled.div({
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    height: '100%',
})
