import styled from '@emotion/styled'
import { Dropdown, Typography } from 'antd'
import { useEffect, useMemo, useState } from 'react'
import { useSelector } from 'react-redux'
import { NavLink } from 'react-router-dom'
import web3 from '../../service/web3'
import { web3Selector } from '../../store/selector/web3Selector'

export function UserDropdown() {
    const user = useSelector(web3Selector.user)
    const [balance, setBalance] = useState('')

    useEffect(() => {
        const getBalance = async (email: string) => {
            const balance = await web3.eth.getBalance(email)
            const ethBalance = web3.utils.fromWei(balance, 'ether')
            setBalance(ethBalance)
        }

        if (user?.email) {
            getBalance(user.email)
        }
    }, [])

    const overlay = useMemo(
        () => (
            <OverlayContainer>
                <Typography.Text strong>잔액: {balance} ETF</Typography.Text>
            </OverlayContainer>
        ),
        [balance],
    )

    return (
        <Dropdown overlay={overlay}>
            <Text>{user?.nickname}</Text>
        </Dropdown>
    )
}

const Text = styled(Typography.Text)({
    fontWeight: 'bold',
    padding: '0 12px',
    color: 'black',
    [`&:hover`]: {
        color: '#9e593c',
    },
})

const OverlayContainer = styled.div`
    background-color: white;
    padding: 12px;
    border-radius: 10px;
    border: 1px solid rgba(0, 0, 0, 0.3);
    -webkit-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    -webkit-background-clip: padding-box;
    -moz-background-clip: padding-box;
    background-clip: padding-box;
`
