import styled from '@emotion/styled'
import { useEffect, useMemo } from 'react'
import 'react-alice-carousel/lib/alice-carousel.css'
import { Image } from 'antd'
import { Product } from '../../store/model/Product'
import KakaoMapScript from '../shared/KakaoMapScript'
import { ProductDescriptionView } from './ProductDescriptionView'

interface Props {
    product: Product
}

const handleDragStart = (e: { preventDefault: () => any }) => e.preventDefault()

export function ProductDetailView({ product }: Props) {
    const { address, imageUrls } = product

    useEffect(() => {
        KakaoMapScript(address)
    }, [address])

    const items = useMemo(
        () =>
            imageUrls.map((image) => (
                <Image
                    src={image ?? '/anjun-logo.png'}
                    alt="logo"
                    width={200}
                    height={200}
                />
            )),
        [imageUrls],
    )

    return (
        <div
            style={{
                display: 'flex',
                flexDirection: 'column',
                width: '100%',
                height: '100%',
                overflow: 'scroll',
            }}
        >
            <div
                id="myMap"
                style={{
                    width: '100%',
                    height: '300px',
                }}
            />

            <ImageContainer>{items}</ImageContainer>

            <ProductDescriptionView product={product} />
        </div>
    )
}

const ImageContainer = styled.div({
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'flex-start',
    marginTop: 12,
    marginBottom: 6,
    paddingLeft: 12,
    [`& > * + *`]: {
        marginLeft: 6,
    },
})
