import styled from '@emotion/styled'
import { Button, Typography } from 'antd'
import { useNavigate } from 'react-router-dom'
import { Product } from '../../store/model/Product'
import { ProductView } from './ProductView'

interface Props {
    products: Array<Product>
    selectedProductId?: number
}

export function ProductListView({ products, selectedProductId }: Props) {
    const navigate = useNavigate()
    return (
        <ProductListContainer>
            <Header>
                <Typography.Text
                    strong
                >{`매물 목록 ${products.length}개`}</Typography.Text>
                <Button
                    type="primary"
                    onClick={() => navigate('/product/create')}
                >
                    매물 생성하기
                </Button>
            </Header>

            {products.map((product) => (
                <ProductView
                    key={product.productId}
                    product={product}
                    selectedProductId={selectedProductId}
                />
            ))}
        </ProductListContainer>
    )
}

const ProductListContainer = styled.div({
    display: 'flex',
    flexDirection: 'column',
    borderRight: '1px solid #F0F0F0;',
    minWidth: 420,
    maxWidth: 420,
    overflow: 'scroll',
})

const Header = styled.div({
    display: 'flex',
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    padding: 12,
    borderTop: '1px solid #F0F0F0;',
    borderBottom: '1px solid #F0F0F0',
})
