import styled from '@emotion/styled'
import _ from 'lodash'
import { useEffect } from 'react'
import { useSelector } from 'react-redux'
import { useAppDispatch } from '../../store'
import { productActions } from '../../store/reducer/productReducer'
import { productSelector } from '../../store/selector/productSelector'
import { web3Selector } from '../../store/selector/web3Selector'
import { ProductDetailView } from './ProductDetailView'
import { ProductListView } from './ProductListview'

export function ProductScreen() {
    const dispatch = useAppDispatch()
    const userId = useSelector(web3Selector.userId)
    const products = useSelector(productSelector.products)
    const product = useSelector(productSelector.selectedProduct)

    useEffect(() => {
        userId !== undefined &&
            dispatch(productActions.getProducts({ userId })).then(
                ({ payload }) => {
                    dispatch(
                        productActions.selectProduct(
                            _.get(_.get(payload, 0), 'productId'),
                        ),
                    )
                },
            )
    }, [])

    return (
        <ProductScreenContainer>
            <ProductListView
                selectedProductId={product?.productId}
                products={products}
            />
            {product && <ProductDetailView product={product} />}
        </ProductScreenContainer>
    )
}

const ProductScreenContainer = styled.div({
    display: 'flex',
    flexDirection: 'row',
    height: '100%',
})
