import styled from '@emotion/styled'
import { useCallback } from 'react'
import { Image, Typography } from 'antd'
import _ from 'lodash'
import { useAppDispatch } from '../../store'
import { Product } from '../../store/model/Product'
import { productActions } from '../../store/reducer/productReducer'

interface Props {
    product: Product
    selectedProductId?: number
}

export function ProductView({ product, selectedProductId }: Props) {
    const dispatch = useAppDispatch()
    const {
        address,
        buildingFormat,
        roomArchitecture,
        area,
        imageUrls,
        description,
        productId,
    } = product

    const handleProductClick = useCallback(() => {
        dispatch(productActions.selectProduct(productId))
    }, [productId])

    return (
        <ProductContainer
            onClick={handleProductClick}
            style={{ cursor: 'pointer', width: 420 }}
            selected={product.productId === selectedProductId}
        >
            <Image
                width={200}
                height={200}
                style={{ minWidth: 200 }}
                src={_.get(imageUrls, 0) ?? '/anjun-logo.png'}
                preview={false}
            />

            <DescriptionContainer>
                <Typography.Text strong>{address}</Typography.Text>
                <Typography.Text>{buildingFormat}</Typography.Text>
                <Typography.Text>{roomArchitecture}</Typography.Text>
                <Typography.Text>
                    {area}m<sup>2</sup>
                </Typography.Text>
                <Typography.Paragraph
                    style={{ whiteSpace: 'pre-wrap', wordBreak: 'break-all' }}
                    ellipsis={{
                        rows: 4,
                        tooltip: description,
                    }}
                >
                    {description}
                </Typography.Paragraph>
            </DescriptionContainer>
        </ProductContainer>
    )
}

const ProductContainer = styled.div(({ selected }: { selected: boolean }) => ({
    display: 'flex',
    flexDirection: 'row',
    padding: 10,
    backgroundColor: selected ? '#fafafa' : 'white',
    width: 420,
}))

const DescriptionContainer = styled.div({
    display: 'flex',
    flexDirection: 'column',
    padding: 10,
})
