import moment from 'moment'
import client from '../../service/client'
import { auction } from '../../service/web3'
import { Auction, AuctionState } from '../model/Auction'

interface AuctionAPI {
    completeAuction: (data: {
        auctionId: number
        account: string
    }) => Promise<Auction>

    createAuction: (data: {
        userId: number
        productId: number
        account: string
        endAt: string
    }) => Promise<Auction>

    getCreatedAuctions: (data: {
        userId: number
        aunctionState?: AuctionState
    }) => Promise<Array<Auction>>

    getBiddedAuctions: (data: {
        userId: number
        aunctionState?: AuctionState
    }) => Promise<Array<Auction>>

    getAuctions: (data: {
        aunctionState?: AuctionState
    }) => Promise<Array<Auction>>
}

export const AuctionAPI = (() => {
    const completeAuction: AuctionAPI['completeAuction'] = async ({
        account,
        auctionId,
    }) =>
        client
            .post('api/v1/auctions/complete', { account, auctionId })
            .then(async (res) => {
                await auction.methods
                    .add(
                        res.data.auctionId,
                        moment(res.data.endAt).diff(moment(), 'seconds'),
                        account,
                    )
                    .send({
                        from: account,
                        gas: 15000000,
                        gasPrice: '300000000000',
                    })

                return res.data
            })

    const createAuction: AuctionAPI['createAuction'] = async ({
        account,
        ...data
    }) =>
        client.post('api/v1/auctions/create', data).then(async (res) => {
            console.log('create', account, res.data.endAt, res.data.auctionId)
            // console.log('seconds', moment(res.data.endAt).asSeconds())
            console.log(
                'seconds',
                moment(res.data.endAt).diff(moment(), 'seconds'),
            )
            await auction.methods
                .add(
                    res.data.auctionId,
                    moment(res.data.endAt).diff(moment(), 'seconds'),
                    account,
                )
                .send({
                    from: account,
                    gas: 0,
                    gasPrice: '3000000000',
                })

            return res.data
        })

    const getCreatedAuctions: AuctionAPI['getCreatedAuctions'] = ({ userId }) =>
        client
            .get('api/v1/auctions', {
                params: {
                    userId,
                    isMyBid: false,
                },
            })
            .then((res) => res.data)

    const getBiddedAuctions: AuctionAPI['getBiddedAuctions'] = ({ userId }) =>
        client
            .get('api/v1/auctions', {
                params: {
                    userId,
                    isMyBid: true,
                },
            })
            .then((res) => res.data)

    const getAuctions: AuctionAPI['getAuctions'] = ({ aunctionState }) =>
        client
            .get('api/v1/auctions', {
                params: {
                    isMyBid: false,
                },
            })
            .then((res) => res.data)

    return Object.freeze({
        createAuction,
        completeAuction,
        getCreatedAuctions,
        getBiddedAuctions,
        getAuctions,
    })
})()
