import client from '../../service/client'
import { Product } from '../model/Product'

interface ProductAPI {
    createProduct: (data: {
        userId: number
        product: Product
    }) => Promise<Product>

    getProducts: (data: { userId: number }) => Promise<Array<Product>>

    uploadImage: (data: Blob) => Promise<string>
}

export const ProductAPI = (() => {
    const createProduct: ProductAPI['createProduct'] = ({ userId, product }) =>
        client
            .post('api/v1/products/create', { userId, ...product })
            .then((res) => res.data)

    const getProducts: ProductAPI['getProducts'] = (data) =>
        client.get('api/v1/products', { params: data }).then((res) => res.data)

    const uploadImage: ProductAPI['uploadImage'] = (data) => {
        const formData = new FormData()
        formData.append('image', data)

        return client
            .post('api/v1/products/upload/image', formData, {
                headers: {
                    'Content-Type': `multipart/form-data`,
                },
            })
            .then((res) => res.data)
    }
    return Object.freeze({
        createProduct,
        getProducts,
        uploadImage,
    })
})()
