import { createAsyncThunk, createSlice } from '@reduxjs/toolkit'
import { BidAPI } from '../api/BidAPI'

export const createBid = createAsyncThunk(
    'GET/createBid',
    async ({
        userId,
        price,
        auctionId,
        account,
    }: {
        userId: number
        price: number
        auctionId: number
        account: string
    }) => BidAPI.createBid({ userId, price, auctionId, account }),
)

interface InitialState {
    isLoading: boolean
}

const initialState: InitialState = {
    isLoading: false,
}

const bidSlice = createSlice({
    name: 'product',
    initialState,
    reducers: {},
    extraReducers: (builder) => {
        builder
            .addCase(createBid.pending, (state) => {
                state.isLoading = true
            })
            .addCase(createBid.fulfilled, (state) => {
                state.isLoading = false
            })
    },
})

export const bidActions = {
    ...bidSlice.actions,
    createBid,
}

export default bidSlice
