import { createAsyncThunk, createSlice, PayloadAction } from '@reduxjs/toolkit'
import _ from 'lodash'
import { ProductAPI } from '../api/productAPI'
import { initialProduct, Product } from '../model/Product'

export const createProduct = createAsyncThunk(
    'GET/createProduct',
    async ({ userId, product }: { userId: number; product: Product }) =>
        ProductAPI.createProduct({ userId, product }),
)

export const getProducts = createAsyncThunk(
    'GET/getProducts',
    async ({ userId }: { userId: number }) =>
        ProductAPI.getProducts({ userId }),
)

export const uploadImage = createAsyncThunk(
    'GET/uploadImage',
    async ({ file }: { file: File }) => ProductAPI.uploadImage(file),
)

interface InitialState {
    product?: Product
    products: Array<Product>
    isLoading: boolean
}

const initialState: InitialState = {
    products: [] as Array<Product>,
    isLoading: false,
}

const productSlice = createSlice({
    name: 'product',
    initialState,
    reducers: {
        selectProduct: (state, action: PayloadAction<number>) => {
            state.product = _.find(
                state.products,
                (product) => product.productId === action.payload,
            )
        },
    },
    extraReducers: (builder) => {
        builder
            .addCase(getProducts.pending, (state) => {
                state.isLoading = true
            })
            .addCase(getProducts.fulfilled, (state, action) => {
                state.isLoading = false
                state.products = action.payload
            })
            .addCase(uploadImage.pending, (state) => {
                state.isLoading = true
            })
            .addCase(uploadImage.fulfilled, (state) => {
                state.isLoading = false
            })
            .addCase(createProduct.pending, (state) => {
                state.isLoading = true
            })
            .addCase(createProduct.fulfilled, (state, action) => {
                state.isLoading = false
                state.product = action.payload
            })
    },
})

export const productActions = {
    ...productSlice.actions,
    getProducts,
    createProduct,
    uploadImage,
}

export default productSlice
