import { createAsyncThunk, createSlice } from '@reduxjs/toolkit'
import web3 from '../../service/web3'
import localStorageAPI from '../../service/localStorage'
import { User } from '../model/User'
import { SignupAPI } from '../api/SignupAPI'
import { ABI } from '../../config'

export const getUser = createAsyncThunk('GET/USER', async () => {
    const accounts = await web3.eth.requestAccounts()
    const user = await localStorageAPI.getUser(accounts[0])

    return { user, account: accounts[0] }
})

export const signin = createAsyncThunk(
    'POST/SIGNIN',
    async ({ email, password }: { email: string; password: string }) => {
        const user = await SignupAPI.signin({ email, password })
        localStorageAPI.signup(user)
        return user
    },
)

export const signup = createAsyncThunk(
    'POST/SIGNUP',
    async ({
        email,
        nickname,
        password,
    }: {
        email: string
        nickname: string
        password: string
    }) => {
        const user = await SignupAPI.signup({ email, nickname, password })
        localStorageAPI.signup(user)
        return user
    },
)

interface InitialState {
    email?: string
    user?: User
    isSignup: boolean
    isEmailLoading: boolean
}

const initialState: InitialState = {
    isSignup: false,
    isEmailLoading: true,
}

const web3Slice = createSlice({
    name: 'web3',
    initialState,
    reducers: {},
    extraReducers: (builder) => {
        builder
            .addCase(getUser.pending, (state) => {
                state.isEmailLoading = true
            })
            .addCase(getUser.fulfilled, (state, action) => {
                state.email = action.payload.account
                state.isEmailLoading = false
                if (action.payload.user) {
                    state.user = action.payload.user
                    state.isSignup = true
                } else {
                    state.user = undefined
                    state.isSignup = false
                }
            })
            .addCase(signin.fulfilled, (state, action) => {
                if (action.payload) {
                    state.user = action.payload
                    state.isSignup = true
                } else {
                    state.user = undefined
                    state.isSignup = false
                }
            })
            .addCase(signup.fulfilled, (state, action) => {
                if (action.payload) {
                    state.user = action.payload
                    state.isSignup = true
                } else {
                    state.user = undefined
                    state.isSignup = false
                }
            })
    },
})

export const web3Actions = {
    ...web3Slice.actions,
    getUser,
    signin,
    signup,
}

export default web3Slice
