import { createSelector } from '@reduxjs/toolkit'
import _ from 'lodash'
import { RootState } from '..'
import { Auction, AuctionState } from '../model/Auction'
import { auctionAdapter } from '../reducer/aunctionReducer'

const auctionState = (state: RootState) => state.auction
const auctionAdapterSelector = auctionAdapter.getSelectors()

const completedFilter = (auction: Auction) =>
    auction.auctionState === AuctionState.COMPLETED

const processingFilter = (auction: Auction) =>
    auction.auctionState === AuctionState.PROCESSING

const auctions = createSelector(auctionState, (state) =>
    auctionAdapterSelector.selectAll(state.auctions),
)

const completedAuctions = createSelector(auctions, (auctions) =>
    _.filter(auctions, completedFilter),
)

const processingAuctions = createSelector(auctions, (auctions) =>
    _.filter(auctions, processingFilter),
)
const biddedAuctions = createSelector(auctionState, (state) =>
    auctionAdapterSelector.selectAll(state.biddedAuctions),
)

const createdAuctions = createSelector(auctionState, (state) =>
    auctionAdapterSelector.selectAll(state.createdAuctions),
)

const completedCreatedAuctions = createSelector(
    createdAuctions,
    (createdAuctions) => _.filter(createdAuctions, completedFilter),
)

const processingCreatedAuctions = createSelector(
    createdAuctions,
    (createdAuctions) => _.filter(createdAuctions, processingFilter),
)

const completedBiddedAuctions = createSelector(
    biddedAuctions,
    (biddedAuctions) => _.filter(biddedAuctions, completedFilter),
)

const processingBiddedAuctions = createSelector(
    biddedAuctions,
    (biddedAuctions) => _.filter(biddedAuctions, processingFilter),
)

const selectedId = createSelector(
    auctionState,
    (state) => state.selectedAuctionId,
)

const auctionArray = createSelector(auctionState, (state) => state.auctions)
const biddedAuctionArray = createSelector(
    auctionState,
    (state) => state.biddedAuctions,
)
const createdAuctionArray = createSelector(
    auctionState,
    (state) => state.createdAuctions,
)

const selectedAuction = createSelector(
    auctionArray,
    selectedId,
    (auctionArray, selectedId) =>
        auctionAdapterSelector.selectById(auctionArray, selectedId),
)

const selectedBiddedAuction = createSelector(
    biddedAuctionArray,
    selectedId,
    (biddedAuctionArray, selectedId) =>
        auctionAdapterSelector.selectById(biddedAuctionArray, selectedId),
)

const selectedCreatedAuction = createSelector(
    createdAuctionArray,
    selectedId,
    (createdAuctionArray, selectedId) =>
        auctionAdapterSelector.selectById(createdAuctionArray, selectedId),
)

export const auctionSelector = {
    processingAuctions,
    completedAuctions,
    biddedAuctions,
    completedCreatedAuctions,
    processingCreatedAuctions,
    completedBiddedAuctions,
    processingBiddedAuctions,
    auctions,
    selectedAuction,
    selectedBiddedAuction,
    selectedCreatedAuction,
}
