import { UploadFile } from 'antd/lib/upload/interface'
import _ from 'lodash'
import { v4 as uuid } from 'uuid'

type ImageResolution = {
    width: number
    height: number
}

export const imageUrlToUploadFile = (imageUrl: string): UploadFile => ({
    uid: uuid(),
    url: imageUrl,
    status: 'done',
    name: imageUrl.substring(imageUrl.lastIndexOf('/') + 1),
    response: imageUrl,
})

export const imageUrlsToUploadFile = (
    imageUrls: Array<string>,
): Array<UploadFile> => imageUrls.map(imageUrlToUploadFile)

export const uploadFilesToImageUrl = (
    uploadFiles: Array<UploadFile>,
): Array<string> =>
    _.compact(uploadFiles.map((uploadFile) => uploadFile.response))

export const uploadFileToImageUrl = (uploadFile: UploadFile): string =>
    uploadFile.response

export const isFileSizeLessOrEqualTo = (
    { size }: File,
    maxFileSizeInMegabytes: number,
) => {
    const fileSizeInMegaBytes = size / 1024 / 1024
    return fileSizeInMegaBytes <= maxFileSizeInMegabytes
}

const imageResolutionFromFile = (file: File) =>
    new Promise<ImageResolution>((resolve) => {
        const reader = new FileReader()
        reader.readAsDataURL(file)
        reader.addEventListener('load', (event) => {
            // eslint-disable-next-line no-underscore-dangle
            const _loadedImageUrl = event?.target?.result as string
            const img = new Image()
            img.onload = () => {
                resolve({
                    width: img.width,
                    height: img.height,
                })
            }
            img.src = _loadedImageUrl
            img.remove()
        })
    })

const imageResolutionFromImageUrl = (imageUrl: string) =>
    new Promise<ImageResolution>((resolve) => {
        const img = new Image()
        img.onload = () => {
            resolve({
                width: img.width,
                height: img.height,
            })
        }
        img.src = imageUrl
        img.remove()
    })

export const isImageResolutionEqualTo = async (
    value: string | File,
    targetResolution: ImageResolution,
) => {
    const { width: targetWidth, height: targetHeight } = targetResolution
    const { width, height } =
        typeof value === 'string'
            ? await imageResolutionFromImageUrl(value)
            : await imageResolutionFromFile(value)
    return {
        isEqual: width === targetWidth && height === targetHeight,
        imageResolution: { width, height },
    }
}
